@@ -1,3 +1,3 @@
-"convhulln" <-
+"convhullnew" <-
 function (p, options = " ") 
 .Call("convhullnew", as.matrix(p), as.character(options),PACKAGE="LogConcDEAD")
